@@ -38,7 +38,7 @@ fwiRaster <- function(input, init = c(ffmc = 85, dmc = 6, dc = 15), mon = 7,
   #                   considerably. (TRUE/FALSE, default TRUE)
   #       
   #
-  # Returns: A data.frame of the calculated FWI values with or without
+  # Returns: A raster stack of the calculated FWI values with or without
   #          the input data attached to it.
   #
   #############################################################################
@@ -75,7 +75,7 @@ fwiRaster <- function(input, init = c(ffmc = 85, dmc = 6, dc = 15), mon = 7,
     lat <- input$lat
   }else {
     lat <- temp
-    values(lat) <- 55
+    raster::values(lat) <- 55
   }
   
   if (!exists("temp") | is.null(temp)) 
@@ -101,9 +101,9 @@ fwiRaster <- function(input, init = c(ffmc = 85, dmc = 6, dc = 15), mon = 7,
       names(init)<-c('ffmc', 'dmc', 'dc')
     }
     ffmc_yda <- dmc_yda <- dc_yda <- temp
-    values(ffmc_yda) <- init[['ffmc']]
-    values(dmc_yda) <- init[['dmc']]
-    values(dc_yda) <- init[['dc']]
+    raster::values(ffmc_yda) <- init[['ffmc']]
+    raster::values(dmc_yda) <- init[['dmc']]
+    raster::values(dc_yda) <- init[['dc']]
   } else {
     ffmc_yda <- init$ffmc
     dmc_yda  <- init$dmc
@@ -115,17 +115,17 @@ fwiRaster <- function(input, init = c(ffmc = 85, dmc = 6, dc = 15), mon = 7,
   #                    Fine Fuel Moisture Code (FFMC)
   ###########################################################################
   #Eq. 1
-  wmo <- 147.2 * (101 - ffmc_yda)/(59.5 + ffmc_yda)
+  wmo <- 147.27723 * (101 - ffmc_yda)/(59.5 + ffmc_yda)
   #Eq. 2 Rain reduction to allow for loss in overhead canopy
   ra1 <- prec
   ra1[ra1 <= 0.5] <- NA
   ra1 <- ra1-0.5
   ra2 <- prec
   ra2[ra2 > 0.5] <- NA
-  ra <- cover(ra1, ra2)
+  ra <- raster::cover(ra1, ra2)
   #masking values
-  wmo1 <- mask(wmo, ra1)
-  wmo2 <- mask(wmo,ra2)
+  wmo1 <- raster::mask(wmo, ra1)
+  wmo2 <- raster::mask(wmo,ra2)
   wmo11 <- wmo1
   wmo11[wmo11 <= 150] <- NA
   ra11 <- ra1
@@ -139,8 +139,8 @@ fwiRaster <- function(input, init = c(ffmc = 85, dmc = 6, dc = 15), mon = 7,
   ra12[wmo1 > 150] <- NA
   wmo12 <- wmo12 + 42.5 * ra12 * exp(-100 / (251 - wmo12)) * 
           (1 - exp(-6.93 / ra12))
-  wmo1 <- cover(wmo11, wmo12)
-  wmo <- cover(wmo1, wmo2)
+  wmo1 <- raster::cover(wmo11, wmo12)
+  wmo <- raster::cover(wmo1, wmo2)
   #The real moisture content of pine litter ranges up to about 250 percent,
   # so we cap it at 250
   wmo[wmo > 250] <- 250
@@ -153,54 +153,54 @@ fwiRaster <- function(input, init = c(ffmc = 85, dmc = 6, dc = 15), mon = 7,
   ew <- 0.618 * (rh^0.753) + (10 * exp((rh - 100)/10)) + 0.18 * 
     (21.1 - temp) * (1 - 1/exp(rh * 0.115))
   #Create a new raster object based on wmo, ed, and ew
-  z0 <- overlay(wmo, ed, ew, fun = function(a, b, c){ return(a < b & a < c) })
+  z0 <- raster::overlay(wmo, ed, ew, fun = function(a, b, c){ return(a < b & a < c) })
   #Create new rasters and mask out missing values
   z0[z0 == 0] <- NA
-  rh0 <- mask(rh, z0)
-  ws0 <- mask(ws, z0)
+  rh0 <- raster::mask(rh, z0)
+  ws0 <- raster::mask(ws, z0)
   #Eq. 6a (ko) Log drying rate at the normal termperature of 21.1 C
   z <- 0.424 * (1 - (((100 - rh0)/100)^1.7)) + 0.0694 * sqrt(ws0) * (1 - ((100 - rh0)/100)^8)
   # Assigning to 0 instead of NA, as 0 makes more sense
   z[is.na(z)] <- 0
   # Mask missing temp values
-  z <- mask(z, temp)
+  z <- raster::mask(z, temp)
   rm(rh0, ws0, z0)
   #Eq. 6b Affect of temperature on  drying rate
   x <- z * 0.581 * exp(0.0365 * temp)
   #Create a new raster object based on wmo, ed, and ew
-  z0 <- overlay(wmo, ed, ew, fun = function(a, b, c){ return(a < b & a < c) })
+  z0 <- raster::overlay(wmo, ed, ew, fun = function(a, b, c){ return(a < b & a < c) })
   #Create new rasters and mask out missing values
   z0[z0 == 0] <- NA
-  ew0 <- mask(ew, z0)
-  x0 <- mask(x, z0)
-  wmo0 <- mask(wmo, z0)
+  ew0 <- raster::mask(ew, z0)
+  x0 <- raster::mask(x, z0)
+  wmo0 <- raster::mask(wmo, z0)
   #Eq. 8
   wmo1 <- ew0 - (ew0 - wmo0) / (10^x0)
   wmo2 <- wmo
   wmo2[!is.na(wmo0)] <- NA
-  wm <- cover(wmo1, wmo2)
+  wm <- raster::cover(wmo1, wmo2)
   rm(z0, ew0, x0, wmo0, wmo1, wmo2)
   #Create a new raster object based on wmo, and ed
-  z0 <- overlay(wmo, ed, fun = function(a, b){ return(a > b) }) 
+  z0 <- raster::overlay(wmo, ed, fun = function(a, b){ return(a > b) }) 
   #Create new rasters and mask out missing values
   z0[z0 == 0] <- NA
-  rh0 <- mask(rh, z0)
-  ws0 <- mask(ws, z0)
+  rh0 <- raster::mask(rh, z0)
+  ws0 <- raster::mask(ws, z0)
   #Eq. 7a (ko) Log wetting rate at the normal termperature of 21.1 C   
   z0 <- 0.424 * (1 - (rh0 / 100)^1.7) + 0.0694 * sqrt(ws0) * (1 - (rh0 / 100)^8)
   z1 <- z
   z1[!is.na(z0)] <- NA
-  z <- cover(z0, z1)
+  z <- raster::cover(z0, z1)
   rm(rh0, ws0)
   #Eq. 7b Affect of temperature on  wetting rate
   x <- z * 0.581 * exp(0.0365 * temp)
   ed0 <- mask(ed,z0)
-  wmo0 <- mask(wmo,z0)
-  x0 <- mask(x,z0)
+  wmo0 <- raster::mask(wmo,z0)
+  x0 <- raster::mask(x,z0)
   #Eq. 9
   wm0 <- ed0 + (wmo0 - ed0)/(10^x0)
-  wm1 <- mask(wm, z1)
-  wm <- cover(wm0, wm1)
+  wm1 <- raster::mask(wm, z1)
+  wm <- raster::cover(wm0, wm1)
   rm(ed0, x0, wm0, wm1, wmo0)
   #Eq. 10 Final FFMC calculation
   ffmc <- (59.5 * (250 - wm))/(147.2 + wm)
@@ -289,7 +289,7 @@ fwiRaster <- function(input, init = c(ffmc = 85, dmc = 6, dc = 15), mon = 7,
   #Eq. 24 - Wind Effect
   fW <- exp(0.05039 * ws)
   #Eq. 10 - Moisture content
-  fm <- 147.2 * (101 - ffmc) / (59.5 + ffmc)
+  fm <- 147.27723 * (101 - ffmc) / (59.5 + ffmc)
   #Eq. 25 - Fine Fuel Moisture
   fF <- 91.9 * exp(-0.1386 * fm) * (1 + (fm^5.31) / 49300000)
   #Eq. 26 - Spread Index Equation
@@ -329,7 +329,7 @@ fwiRaster <- function(input, init = c(ffmc = 85, dmc = 6, dc = 15), mon = 7,
   #If output specified is "fwi", then return only the FWI variables
   if (out == "fwi") {
     #Creating a raster stack of FWI variables to return
-    new_FWI <- stack(ffmc, dmc, dc, isi, bui, fwi, dsr)
+    new_FWI <- raster::stack(ffmc, dmc, dc, isi, bui, fwi, dsr)
     names(new_FWI) <- c("ffmc", "dmc", "dc", "isi", "bui", "fwi", "dsr")
     if (uppercase){
       names(new_FWI) <- toupper(names(new_FWI))
@@ -338,7 +338,7 @@ fwiRaster <- function(input, init = c(ffmc = 85, dmc = 6, dc = 15), mon = 7,
   } else {
     if (out == "all") {
       #Create a raster stack of input and FWI variables
-      new_FWI <- stack(input, ffmc, dmc, dc, isi, bui, fwi, dsr)
+      new_FWI <- raster::stack(input, ffmc, dmc, dc, isi, bui, fwi, dsr)
       names(new_FWI) <- c(names(input),"ffmc", "dmc", "dc", "isi", "bui", "fwi", "dsr")
       if (uppercase){
         names(new_FWI) <- toupper(names(new_FWI))
