@@ -26,7 +26,7 @@ hffmcRaster <- function(weatherstream, ffmc_old = 85, time.step = 1,
   #              Headquarters, Ottawa. Forestry Technical Report 35. 35 p.
   #  
   #
-  # Args: weatherstream:   Input weather stream data.frame which includes
+  # Args: weatherstream:   Input weather stream raster stack which includes
   #                        temperature, relative humidity, wind speed, 
   #                        precipitation, hourly value, and bui. More specific
   #                        info can be found in the hffmc.Rd help file.
@@ -47,7 +47,7 @@ hffmcRaster <- function(weatherstream, ffmc_old = 85, time.step = 1,
   #Check that the parameters are correct
   if (is.numeric(ffmc_old)){
     Fo <- Tp
-    values(Fo)<-ffmc_old
+    raster::values(Fo)<-ffmc_old
   }else{Fo<-ffmc_old}
   if (!exists("Tp") | is.null(Tp)) 
     warning("temperature (temp) is missing!")
@@ -63,27 +63,27 @@ hffmcRaster <- function(weatherstream, ffmc_old = 85, time.step = 1,
   mr1 <- mo
   mr1[mr1 > 150] <- NA
   #masking values
-  rf1 <- mask(ro, mr1)
+  rf1 <- raster::mask(ro, mr1)
   #Eqs. 3a (Van Wagner & Pickett 1985)
   mr1 <- mr1 + 42.5 * rf1 * exp(-100 / (251 - mr1)) * (1 - exp(-6.93 / rf1))
   mr2 <- mo
   mr2[mr2 <= 150] <- NA
-  rf2 <- mask(ro, mr2)
+  rf2 <- raster::mask(ro, mr2)
   #Eqs. 3b (Van Wagner & Pickett 1985)
   mr2 <- mr2 + 42.5 * rf2 * exp(-100 / (251 - mr2)) *(1 - exp(-6.93 / rf2)) + 
          0.0015 * ((mr2 - 150)^2) * (rf2^0.5)
-  mr3 <- cover(mr1,mr2)
+  mr3 <- raster::cover(mr1,mr2)
   #The real moisture content of pine litter ranges up to about 250 percent,
   # so we cap it at 250
   mr3[mr3 > 250] <- 250
   #raster manipulation to speed up processing
   r1 <- ro
   r1[r1 <= 0] <- NA
-  mr<-mask(mr3, r1)
+  mr<- raster::mask(mr3, r1)
   r1 <- ro
   r1[r1 > 0] <- NA
-  mo1 <- mask(mo, r1)
-  mo <- cover(mo1, mr)
+  mo1 <- raster::mask(mo, r1)
+  mo <- raster::cover(mo1, mr)
   #Eq. 2a Equilibrium moisture content from drying
   Ed <- 0.942 * (H^0.679) + 11 * exp((H - 100)/10) + 0.18 * (21.1 - Tp) * 
         (1 - exp(-0.115 * H))
@@ -104,15 +104,15 @@ hffmcRaster <- function(weatherstream, ffmc_old = 85, time.step = 1,
   #Eq. 8 (Van Wagner & Pickett 1985)
   mw <- Ew - (Ew - mo) * (10^(-1*kw*time.step)) 
   #Constraints using raster manipulation
-  m0 <- overlay(mo, Ed, fun = function(a, b){ return(a > b) })
+  m0 <- raster::overlay(mo, Ed, fun = function(a, b){ return(a > b) })
   md[m0 == 0] <- NA
   mw[m0 == 1] <- NA
-  m <- cover(md, mw)
+  m <- raster::cover(md, mw)
 
-  m1 <- overlay(Ed, mo, Ew, fun = function(a, b, c) return(a >= b & b >= c))
+  m1 <- raster::overlay(Ed, mo, Ew, fun = function(a, b, c) return(a >= b & b >= c))
   mo[m1 == 0] <- NA
   m[m1 == 1] <- NA
-  m <- cover(mo, m)
+  m <- raster::cover(mo, m)
   #Eq. 6 - Final hffmc calculation (modified 3rd constant to 147.27723)
   fo <- 59.5 * (250 - m) / (147.27723 + m)
   fo[fo <= 0] <- 0
@@ -123,7 +123,7 @@ hffmcRaster <- function(weatherstream, ffmc_old = 85, time.step = 1,
 
       #Calculate ISI
       fW <- exp(0.05039 * W)
-      fm <- 147.2 * (101 - fo) / (59.5 + fo)
+      fm <- 147.27723 * (101 - fo) / (59.5 + fo)
       fF <- 91.9 * exp(-0.1386 * fm) * (1 + (fm^5.31) / 49300000)
       isi <- 0.208 * fW * fF
       
@@ -135,7 +135,7 @@ hffmcRaster <- function(weatherstream, ffmc_old = 85, time.step = 1,
       bui2 <- bui
       bui2[bui1 > 80] <- NA
       bui2 <- 0.1 * isi * (0.626 * (bui2^0.809) + 2)
-      bb <- cover(bui1, bui2)
+      bb <- raster::cover(bui1, bui2)
       
       bb1 <- bb
       bb1[bb > 1] <- NA
@@ -143,11 +143,11 @@ hffmcRaster <- function(weatherstream, ffmc_old = 85, time.step = 1,
       bb2 <- bb
       bb2[bb <= 1] <- NA
       bb2 <- exp(2.72 * ((0.434 * log(bb2))^0.647))
-      fwi <- cover(bb1, bb2)
+      fwi <- raster::cover(bb1, bb2)
       #Calculate DSR
       dsr <- 0.0272 * (fwi^1.77)
       #Create Raster Stack for the ouput
-      output <- stack(fo, isi, fwi, dsr)
+      output <- raster::stack(fo, isi, fwi, dsr)
       names(output) <- c("hffmc", "hisi", "hfwi", "hdsr")
       return(output)
     } else {
